@@ -54,8 +54,8 @@ downloads, installation and source code.
 
 __Conventions__  = 'CF-1.6'
 __author__       = 'David Hassell'
-__date__         = '2017-08-01'
-__version__      = '2.0.3'
+__date__         = '2017-09-15'
+__version__      = '2.0.4'
 
 from distutils.version import StrictVersion
 import imp
@@ -98,7 +98,7 @@ from .query                import (Query, lt, le, gt, ge, eq, ne, contain,
                                    cellsize, cellge, cellgt, cellle, celllt,
                                    cellwi, cellwo, djf, mam, jja, son, seasons)
 from .flags                import Flags
-from .cellmethods          import CellMethods
+from .cellmethods          import CellMethod, CellMethods
 from .constants            import *
 from .functions            import *
 from .maths                import *
