@@ -1,6 +1,7 @@
 from itertools import izip
 
-from numpy import size as numpy_size
+from numpy import size        as numpy_size
+from numpy import expand_dims as numpy_expand_dims
 
 from .functions    import parse_indices
 from .variable     import Variable, SubspaceVariable
@@ -19,21 +20,12 @@ class BoundedVariable(Variable):
     '''Base class for CF dimension coordinate, auxiliary coordinate and
 domain ancillary objects.
 
-**Attributes**
-
-===============  ========  ===================================================
-Attribute        Type      Description
-===============  ========  ===================================================
-`!climatology`   ``bool``  Whether or not the bounds are intervals of
-                           climatological time. Presumed to be False if unset.
-===============  ========  ===================================================
-
     '''
     def __init__(self, properties={}, attributes={}, data=None,
                  bounds=None, source=None, copy=True):
-        '''
+        '''**Initialization**
 
-**Initialization**
+:Parameters:
 
 :Parameters:
 
@@ -51,11 +43,17 @@ Attribute        Type      Description
     bounds: `cf.Data` or `cf.Bounds`, optional
         Provide the new instance with cell bounds.
 
+    source: `cf.BoundedVariable`, optional
+        Take the attributes, CF properties and data array from the
+        source object. Any attributes, CF properties or data array
+        specified with other parameters are set after initialisation
+        from the source instance.
+
     copy: `bool`, optional
         If False then do not copy arguments prior to
         initialization. By default arguments are deep copied.
 
-'''         
+        '''         
         # DO NOT CHANGE _period IN PLACE
         self._period    = None
 
@@ -76,8 +74,7 @@ Attribute        Type      Description
             self.insert_bounds(bounds, copy=copy)
 
         # Set default standard names based on units
-    #--- End: def 
-
+    #--- End: def
 
     def __getitem__(self, indices):
         '''
@@ -171,6 +168,72 @@ x.__getitem__(indices) <==> x[indices]
         return new
     #--- End: def
 
+    def __eq__(self, y):
+        '''
+
+The rich comparison operator ``==``
+
+x.__eq__(y) <==> x==y
+
+'''
+        return self._binary_operation(y, '__eq__', False)
+    #--- End: def
+
+    def __ne__(self, y):
+        '''
+
+The rich comparison operator ``!=``
+
+x.__ne__(y) <==> x!=y
+
+'''
+        return self._binary_operation(y, '__ne__', False)
+    #--- End: def
+
+    def __ge__(self, y):
+        '''
+
+The rich comparison operator ``>=``
+
+x.__ge__(y) <==> x>=y
+
+'''
+        return self._binary_operation(y, '__ge__', False)
+    #--- End: def
+
+    def __gt__(self, y):
+        '''
+
+The rich comparison operator ``>``
+
+x.__gt__(y) <==> x>y
+
+'''
+        return self._binary_operation(y, '__gt__', False)
+    #--- End: def
+
+    def __le__(self, y):
+        '''
+
+The rich comparison operator ``<=``
+
+x.__le__(y) <==> x<=y
+
+'''
+        return self._binary_operation(y, '__le__', False)
+    #--- End: def
+
+    def __lt__(self, y):
+        '''
+
+The rich comparison operator ``<``
+
+x.__lt__(y) <==> x<y
+
+'''
+        return self._binary_operation(y, '__lt__', False)
+    #--- End: def
+    
     def _query_contain(self, value):
         '''
 
@@ -187,71 +250,67 @@ x.__getitem__(indices) <==> x[indices]
 #        return ((mn <= value) & (mx >= value)).squeeze(axes=-1, i=True)
     #--- End: def
 
-#    def _binary_operation(self, other, method):
-#        '''Implement binary arithmetic and comparison operations on the
-#{+variable}'s Data with the numpy broadcasting rules. It is intended
-#to be called by the binary arithmetic and comparison methods, such as
-#`!__sub__` and `!__lt__`.
-#
-#:Parameters:
-#
-#    other:
-#
-#    method: `str`
-#        The binary arithmetic or comparison method name (such as
-#        ``'__imul__'`` or ``'__ge__'``).
-#
-#:Returns:
-#
-#    new: `cf.+{Variable}`
-#        A new {+variable}, or the same {+variable} if the operation
-#        was in-place.
-#
-#:Examples:
-#
-#        '''
-#        self_hasbounds = self._hasbounds
-#
-#        if isinstance(other, self.__class__):
-#            if other._hasbounds:
-#                if not self_hasbounds:
-#                    raise TypeError("asdfsdfdfds 0000")
-#
-#                other_bounds = other.bounds
-#            elif self_hasbounds:
-#                raise TypeError("asdfsdfdfds 00001")
-#
-#        else:
-#            other_bounds = other
-#            if numpy_size(other) > 1:
-#                raise TypeError("4444444")
-#
-##        elif isinstance(other, (float, int, long)):
-##            other_bounds = other
-##
-##        elif isinstance(other, numpy_ndarray):
-##            if self_hasbounds:
-##                if other.size > 1:
-##                    raise TypeError("4444444")#
-##
-##                other_bounds = other
-#        #-- End: if
-#
-#        inplace = method[2] == 'i'
-#                
-#        new = super(BoundedVariable, self)._binary_operation(other, method)
-#
-#        if self_hasbounds:
-#            new_bounds = self.bounds._binary_operation(other_bounds, method)
-#
-#        if not inplace:
-#            if self_hasbounds:
-#                new.insert_bounds(new_bounds, copy=False)
-#
-#            return new
-#        else: 
-#            return self
-#    #--- End: def
+    def _binary_operation(self, other, method, bounds=True):
+        '''Implement binary arithmetic and comparison operations.
+
+The operations act on the {+variable}'s data array with the numpy
+broadcasting rules.
+
+If the {+variable} has bounds then they are operated on with the same
+data as the the {+variable}'s data array.
+
+It is intended to be called by the binary arithmetic and comparison
+methods, such as `!__sub__` and `!__lt__`.
+
+:Parameters:
+
+    other:
+
+    method: `str`
+        The binary arithmetic or comparison method name (such as
+        ``'__imul__'`` or ``'__ge__'``).
+
+    bounds: `bool`, optional
+
+:Returns:
+
+    new: `cf.+{Variable}`
+        A new {+variable}, or the same {+variable} if the operation
+        was in-place.
+
+:Examples:
+
+        '''
+        inplace = method[2] == 'i'
+
+        hasbounds = bounds and self._hasbounds
+        
+        if hasbounds and inplace and other is self:
+            other = other.copy()
+        
+        new = super(BoundedVariable, self)._binary_operation(other, method)
+
+        if hasbounds:
+            if numpy_size(other) > 1:
+                try:
+                    other = other.expand_dims(-1)
+                except AttributeError:
+                    other = numpy_expand_dims(other, -1)
+                
+            new_bounds = self.bounds._binary_operation(other, method)
+
+            if not inplace:
+                new.insert_bounds(new_bounds, copy=False)
+        #--- End: if
+
+        if not bounds and new._hasbounds:
+            del new.bounds
+            
+        if inplace:
+            return self
+        else:
+            return new
+    #--- End: def
 
     def _change_axis_names(self, dim_name_map):
         '''
@@ -386,9 +445,7 @@ AttributeError: Can't set 'bounds' attribute. Consider the insert_bounds method.
     @bounds.setter
     def bounds(self, value):
         raise AttributeError(
-            "Can't set 'bounds' attribute. Consider the insert_bounds method.")
-#        self._set_special_attr('bounds', value)        
-#        self._hasbounds = True
+            "Can't set 'bounds' attribute. Use the insert_bounds method.")
     #--- End: def
     @bounds.deleter
     def bounds(self):  
@@ -444,9 +501,7 @@ AttributeError: Can't get cell sizes when cells have no bounds
     # ----------------------------------------------------------------
     @property
     def dtype(self):
-        '''
-
-Numpy data-type of the data array.
+        '''Numpy data-type of the data array.
 
 .. versionadded:: 2.0 
 
@@ -457,7 +512,7 @@ dtype('float64')
 >>> import numpy
 >>> c.dtype = numpy.dtype('float32')
 
-'''
+        '''
         if self._hasData:
             return self.Data.dtype
         
@@ -507,11 +562,12 @@ False
     # ----------------------------------------------------------------
     @property
     def lower_bounds(self):
-        '''
+        '''The lower cell bounds.
 
-The lower cell bounds in a `cf.Data` object.
+The lower cell bounds are returned in a `cf.Data` object.
 
-``c.lower_bounds`` is equivalent to ``c.bounds.data.min(axes=-1)``.
+Note that ``c.lower_bounds`` is equivalent to
+``c.bounds.data.min(axes=-1)``.
 
 .. versionadded:: 2.0
 
@@ -528,7 +584,7 @@ The lower cell bounds in a `cf.Data` object.
 >>> print c.lower_bounds.array
 [ 3  1 -1]
 
-'''
+        '''
         if not self._hasbounds:
             raise ValueError("Can't get lower bounds when there are no bounds")
 
@@ -627,9 +683,12 @@ The Units object containing the units of the data array.
     # ----------------------------------------------------------------
     @property
     def upper_bounds(self):
-        '''The upper cell bounds in a `cf.Data` object.
+        '''The upper cell bounds.
 
-``c.upper_bounds`` is equivalent to ``c.bounds.data.max(axes=-1)``.
+The upper cell bounds are returned in a `cf.Data` object.
+
+Note that ``c.upper_bounds`` is equivalent to
+``c.bounds.data.max(axes=-1)``.
 
 .. versionadded:: 2.0 
 
@@ -914,96 +973,96 @@ Partition the data array.
             self.bounds.chunk(chunksize)
     #--- End: def
 
-    def clip(self, a_min, a_max, units=None, i=False):
-        '''
-
-Clip (limit) the values in the data array and its bounds in place.
-
-Given an interval, values outside the interval are clipped to the
-interval edges.
-
-.. versionadded:: 2.0 
-
-Parameters :
- 
-    a_min : scalar
-
-    a_max : scalar
-
-    units : str or Units
-
-    {+i}
-
-:Returns: 
-
-    None
-
-:Examples:
-
-'''
-        c = super(BoundedVariable, self).clip(a_min, a_max, units=units, i=i)
-        
-        if c._hasbounds:
-            # Clip the bounds
-            c.bounds.clip(a_min, a_max, units=units, i=True)
-            
-        return c
-    #--- End: def
+#    def clip(self, a_min, a_max, units=None, i=False):
+#        '''
+#
+#Clip (limit) the values in the data array and its bounds in place.
+#
+#Given an interval, values outside the interval are clipped to the
+#interval edges.
+#
+#.. versionadded:: 2.0 
+#
+#Parameters :
+# 
+#    a_min : scalar
+#
+#    a_max : scalar
+#
+#    units : str or Units
+#
+#    {+i}
+#
+#:Returns: 
+#
+#    None
+#
+#:Examples:
+#
+#'''
+#        c = super(BoundedVariable, self).clip(a_min, a_max, units=units, i=i)
+#        
+#        if c._hasbounds:
+#            # Clip the bounds
+#            c.bounds.clip(a_min, a_max, units=units, i=True)
+#            
+#        return c
+#    #--- End: def
   
-    def close(self):
-        '''
-
-Close all files referenced by the bounded variable.
-
-Note that a closed file will be automatically reopened if its contents
-are subsequently required.
-
-.. versionadded:: 2.0 
-
-:Returns:
-
-    None
-
-:Examples:
-
->>> c.close()
-
-'''
-        new = super(BoundedVariable, self).close()
-        
-        if self._hasbounds:
-            self.bounds.close()
-    #--- End: def
+#    def close(self):
+#        '''
+#
+#Close all files referenced by the bounded variable.
+#
+#Note that a closed file will be automatically reopened if its contents
+#are subsequently required.
+#
+#.. versionadded:: 2.0 
+#
+#:Returns:
+#
+#    None
+#
+#:Examples:
+#
+#>>> c.close()
+#
+#'''
+#        new = super(BoundedVariable, self).close()
+#        
+#        if self._hasbounds:
+#            self.bounds.close()
+#    #--- End: def
 
     @classmethod
-    def concatenate(cls, variables, axis=0, _preserve=True):
-        '''
-Join a sequence of bounded variables together.
-
-.. versionadded:: 2.0 
-
-:Returns:
-
-    out : cf.{+Variable}
-
-'''      
-        variable0 = variables[0]
-
-        if len(variables) == 1:
-            return variables.copy()
-
-        out = Variable.concatenate(variables, axis=axis,
-                                   _preserve=_preserve)
-        
-        if variable0._hasbounds:
-            bounds = Variable.concatenate(
-                [v.bounds for v in variables],
-                axis=axis, _preserve=_preserve)
-
-            out.insert_bounds(bounds, copy=False)
-        
-        return out
-    #--- End: def
+#    def concatenate(cls, variables, axis=0, _preserve=True):
+#        '''
+#Join a sequence of bounded variables together.
+#
+#.. versionadded:: 2.0 
+#
+#:Returns:
+#
+#    out : cf.{+Variable}
+#
+#'''      
+#        variable0 = variables[0]
+#
+#        if len(variables) == 1:
+#            return variables.copy()
+#
+#        out = Variable.concatenate(variables, axis=axis,
+#                                   _preserve=_preserve)
+#        
+#        if variable0._hasbounds:
+#            bounds = Variable.concatenate(
+#                [v.bounds for v in variables],
+#                axis=axis, _preserve=_preserve)
+#
+#            out.insert_bounds(bounds, copy=False)
+#        
+#        return out
+#    #--- End: def
 
     def contiguous(self, overlap=True):
         '''Return True if a {+variable} has contiguous cells.
@@ -1196,96 +1255,96 @@ days since 2000-1-1
         return c
     #--- End: def
 
-    def cos(self, i=False):
-        '''
-
-Take the trigonometric cosine of the data array and bounds in place.
-
-Units are accounted for in the calcualtion, so that the the cosine of
-90 degrees_east is 0.0, as is the sine of 1.57079632 radians. If the
-units are not equivalent to radians (such as Kelvin) then they are
-treated as if they were radians.
-
-The Units are changed to '1' (nondimensionsal).
-
-.. versionadded:: 2.0 
-
-:Parameters:
-
-    {+i}
-
-:Returns:
-
-    out : cf.{+Variable}
-
-:Examples:
-
->>> c.Units
-<CF Units: degrees_east>
->>> print c.array
-[[-90 0 90 --]]
->>> c.cos()
->>> c.Units
-<CF Units: 1>
->>> print c.array
-[[0.0 1.0 0.0 --]]
-
->>> c.Units
-<CF Units: m s-1>
->>> print c.array
-[[1 2 3 --]]
->>> c.cos()
->>> c.Units
-<CF Units: 1>
->>> print c.array
-[[0.540302305868 -0.416146836547 -0.9899924966 --]]
-
-'''
-        if i:
-            c = self
-        else:
-            c = self.copy()
-
-        super(BoundedVariable, c).cos(i=True)
-
-        if c._hasbounds:
-            c.bounds.cos(i=True)
-
-        return c
-    #--- End: def
-
-    def cyclic(self, axes=None, iscyclic=True):
-        '''
-
-Set the cyclicity of axes of the data array and bounds.
-
-.. versionadded:: 2.0 
-
-.. seealso:: `cf.DimensionCoordinate.period`
-
-:Parameters:
-
-    axes : (sequence of) int
-        The axes to be set. Each axis is identified by its integer
-        position. By default no axes are set.
-        
-    iscyclic: bool, optional
-
-:Returns:
-
-    out : list
-
-:Examples:
-
-'''
-        old = super(BoundedVariable, self).cyclic(axes, iscyclic)
-
-        if axes is not None and self._hasbounds:
-            axes = self._parse_axes(axes)
-            self.bounds.cyclic(axes, iscyclic)
-
-        return old
-    #--- End: def
+#    def cos(self, i=False):
+#        '''
+#
+#Take the trigonometric cosine of the data array and bounds in place.
+#
+#Units are accounted for in the calcualtion, so that the the cosine of
+#90 degrees_east is 0.0, as is the sine of 1.57079632 radians. If the
+#units are not equivalent to radians (such as Kelvin) then they are
+#treated as if they were radians.
+#
+#The Units are changed to '1' (nondimensionsal).
+#
+#.. versionadded:: 2.0 
+#
+#:Parameters:
+#
+#    {+i}
+#
+#:Returns:
+#
+#    out : cf.{+Variable}
+#
+#:Examples:
+#
+#>>> c.Units
+#<CF Units: degrees_east>
+#>>> print c.array
+#[[-90 0 90 --]]
+#>>> c.cos()
+#>>> c.Units
+#<CF Units: 1>
+#>>> print c.array
+#[[0.0 1.0 0.0 --]]
+#
+#>>> c.Units
+#<CF Units: m s-1>
+#>>> print c.array
+#[[1 2 3 --]]
+#>>> c.cos()
+#>>> c.Units
+#<CF Units: 1>
+#>>> print c.array
+#[[0.540302305868 -0.416146836547 -0.9899924966 --]]
+#
+#'''
+#        if i:
+#            c = self
+#        else:
+#            c = self.copy()
+#
+#        super(BoundedVariable, c).cos(i=True)
+#
+#        if c._hasbounds:
+#            c.bounds.cos(i=True)
+#
+#        return c
+#    #--- End: def
+#
+#    def cyclic(self, axes=None, iscyclic=True):
+#        '''
+#
+#Set the cyclicity of axes of the data array and bounds.
+#
+#.. versionadded:: 2.0 
+#
+#.. seealso:: `cf.DimensionCoordinate.period`
+#
+#:Parameters:
+#
+#    axes : (sequence of) int
+#        The axes to be set. Each axis is identified by its integer
+#        position. By default no axes are set.
+#        
+#    iscyclic: bool, optional
+#
+#:Returns:
+#
+#    out : list
+#
+#:Examples:
+#
+#'''
+#        old = super(BoundedVariable, self).cyclic(axes, iscyclic)
+#
+#        if axes is not None and self._hasbounds:
+#            axes = self._parse_axes(axes)
+#            self.bounds.cyclic(axes, iscyclic)
+#
+#        return old
+#    #--- End: def
 
     def direction(self):
         '''
@@ -1308,74 +1367,74 @@ None
         return
     #--- End: def
 
-    def tan(self, i=False):
-        '''
+#    def tan(self, i=False):
+#        '''
+#
+#Take the trigonometric tangent of the data array and bounds in place.
+#
+#Units are accounted for in the calculation, so that the the tangent of
+#180 degrees_east is 0.0, as is the sine of 3.141592653589793
+#radians. If the units are not equivalent to radians (such as Kelvin)
+#then they are treated as if they were radians.
+#
+#The Units are changed to '1' (nondimensionsal).
+#
+#.. versionadded:: 2.0 
+#
+#:Parameters:
+#
+#    {+i}
+#
+#:Returns:
+#
+#    out : cf.{+Variable}
+#
+#:Examples:
+#
+#'''
+#        if i:
+#            c = self
+#        else:
+#            c = self.copy()
+#
+#        super(BoundedVariable, c).tan(i=True)
+#
+#        if c._hasbounds:
+#            c.bounds.tan(i=True)
+#
+#        return c
+#    #--- End: def
 
-Take the trigonometric tangent of the data array and bounds in place.
-
-Units are accounted for in the calculation, so that the the tangent of
-180 degrees_east is 0.0, as is the sine of 3.141592653589793
-radians. If the units are not equivalent to radians (such as Kelvin)
-then they are treated as if they were radians.
-
-The Units are changed to '1' (nondimensionsal).
-
-.. versionadded:: 2.0 
-
-:Parameters:
-
-    {+i}
-
-:Returns:
-
-    out : cf.{+Variable}
-
-:Examples:
-
-'''
-        if i:
-            c = self
-        else:
-            c = self.copy()
-
-        super(BoundedVariable, c).tan(i=True)
-
-        if c._hasbounds:
-            c.bounds.tan(i=True)
-
-        return c
-    #--- End: def
-
-    def copy(self, _omit_Data=False, _only_Data=False):
-        '''
-        
-Return a deep copy.
-
-Equivalent to ``copy.deepcopy(c)``.
-
-.. versionadded:: 2.0 
-
-:Returns:
-
-    out :
-        The deep copy.
-
-:Examples:
-
->>> d = c.copy()
-
-'''
-        new = super(BoundedVariable, self).copy(_omit_Data=_omit_Data,
-                                                _only_Data=_only_Data,
-                                                _omit_special=('bounds',))
-
-        if self._hasbounds:
-            bounds = self.bounds.copy(_omit_Data=_omit_Data,
-                                      _only_Data=_only_Data)
-            new._set_special_attr('bounds', bounds)        
-
-        return new
-    #--- End: def
+#    def copy(self, _omit_Data=False, _only_Data=False):
+#        '''
+#        
+#Return a deep copy.
+#
+#Equivalent to ``copy.deepcopy(c)``.
+#
+#.. versionadded:: 2.0 
+#
+#:Returns:
+#
+#    out :
+#        The deep copy.
+#
+#:Examples:
+#
+#>>> d = c.copy()
+#
+#'''
+#        new = super(BoundedVariable, self).copy(_omit_Data=_omit_Data,
+#                                                _only_Data=_only_Data,
+#                                                _omit_special=('bounds',))
+#
+#        if self._hasbounds:
+#            bounds = self.bounds.copy(_omit_Data=_omit_Data,
+#                                      _only_Data=_only_Data)
+#            new._set_special_attr('bounds', bounds)        
+#
+#        return new
+#    #--- End: def
 
     def delprop(self, prop):
         '''
@@ -1489,61 +1548,61 @@ Return a string containing a full description of the variable.
             return string
     #--- End: def
 
-    def expand_dims(self, position=0, i=False):
-        '''Insert a size 1 axis.
-
-.. versionadded:: 2.0 
-
-.. seealso:: `flip`, `squeeze`, `transpose`
-
-:Parameters:
-
-    position : int, optional
-        Specify the position amongst the data array axes where the new
-        axis is to be inserted. By default the new axis is inserted at
-        position 0, the slowest varying position.
-
-    {+i}
-
-:Returns:
-
-    out : cf.{+Variable}
-
-        '''
-        if (not self._hasData and
-            (not self._hasbounds or not self.bounds._hasData)):
-            raise ValueError(
-                "Can't insert axis into {!r}".format(self.__class__.__name__))
-
-        if self._hasData:
-            c = super(BoundedVariable, self).expand_dims(position, i=i)
-        elif i:
-            c = self
-        else:
-            c = self.copy()
-
-        if c._hasbounds and c.bounds._hasData:
-            # Expand the bounds
-            position = self._parse_axes([position])[0]
-            c.bounds.expand_dims(position, i=True)
-
-#        if i:
+#    def expand_dims(self, position=0, i=False):
+#        '''Insert a size 1 axis.
+#
+#.. versionadded:: 2.0 
+#
+#.. seealso:: `flip`, `squeeze`, `transpose`
+#
+#:Parameters:
+#
+#    position : int, optional
+#        Specify the position amongst the data array axes where the new
+#        axis is to be inserted. By default the new axis is inserted at
+#        position 0, the slowest varying position.
+#
+#    {+i}
+#
+#:Returns:
+#
+#    out : cf.{+Variable}
+#
+#        '''
+#        if (not self._hasData and
+#            (not self._hasbounds or not self.bounds._hasData)):
+#            raise ValueError(
+#                "Can't insert axis into {!r}".format(self.__class__.__name__))
+#
+#        if self._hasData:
+#            c = super(BoundedVariable, self).expand_dims(position, i=i)
+#        elif i:
 #            c = self
 #        else:
 #            c = self.copy()
 #
-#        # Expand the coordinate's data, if it has any.
-#        if c._hasData:
-##            super(Coordinate, self).expand_dims(position, i=True)
-#            c.Data.expand_dims(position, i=True)
-#
-#        # Expand the coordinate's bounds, if it has any.
 #        if c._hasbounds and c.bounds._hasData:
-##            c.bounds.expand_dims(position, i=True)
-#            c.bounds.Data.expand_dims(position, i=True)
-
-        return c
-    #--- End: def
+#            # Expand the bounds
+#            position = self._parse_axes([position])[0]
+#            c.bounds.expand_dims(position, i=True)
+#
+##        if i:
+##            c = self
+##        else:
+##            c = self.copy()
+##
+##        # Expand the coordinate's data, if it has any.
+##        if c._hasData:
+###            super(Coordinate, self).expand_dims(position, i=True)
+##            c.Data.expand_dims(position, i=True)
+##
+##        # Expand the coordinate's bounds, if it has any.
+##        if c._hasbounds and c.bounds._hasData:
+###            c.bounds.expand_dims(position, i=True)
+##            c.bounds.Data.expand_dims(position, i=True)
+#
+#        return c
+#    #--- End: def
 
     def flip(self, axes=None, i=False):
         '''Flip dimensions of the data array and bounds in place.
@@ -1611,16 +1670,16 @@ True
         return c
     #--- End: def
 
-    def HDF_chunks(self, *chunksizes):
-        '''
-        '''
-        old_chunks = super(BoundedVariable, self).HDF_chunks(*chunksizes)
- 
-        if self._hasbounds:
-            self.bounds.HDF_chunks(*chunksizes)
-        
-        return old_chunks
-    #--- End: def
+#    def HDF_chunks(self, *chunksizes):
+#        '''
+#        '''
+#        old_chunks = super(BoundedVariable, self).HDF_chunks(*chunksizes)
+# 
+#        if self._hasbounds:
+#            self.bounds.HDF_chunks(*chunksizes)
+#        
+#        return old_chunks
+#    #--- End: def
     
     def insert_bounds(self, bounds, copy=True):
         '''
@@ -1739,30 +1798,30 @@ keyword. Bounds may also be inserted independently with the
         return c
     #--- End: def
 
-    def roll(self, axis, shift, i=False):
-        '''
-
-.. versionadded:: 2.0 
-
-    {+i}
-'''      
-        if self.size <= 1:
-            if i:
-                return self
-            else:
-                return self.copy()
-
-        c = super(BoundedVariable, self).roll(axis, shift, i=i)
-
-        # Roll the bounds, if there are any
-        if c._hasbounds:
-            b = c.bounds
-            if b._hasData:
-                b.roll(axis, shift, i=True)
-        #--- End: if
-
-        return c
-    #--- End: def
+#    def roll(self, axis, shift, i=False):
+#        '''
+#
+#.. versionadded:: 2.0 
+#
+#    {+i}
+#'''      
+#        if self.size <= 1:
+#            if i:
+#                return self
+#            else:
+#                return self.copy()
+#
+#        c = super(BoundedVariable, self).roll(axis, shift, i=i)
+#
+#        # Roll the bounds, if there are any
+#        if c._hasbounds:
+#            b = c.bounds
+#            if b._hasData:
+#                b.roll(axis, shift, i=True)
+#        #--- End: if
+#
+#        return c
+#    #--- End: def
 
     def setprop(self, prop, value):
         '''
@@ -1807,138 +1866,136 @@ Set a CF property.
             self.bounds.setprop(prop, value)
     #--- End: def
 
-    def sin(self, i=False):
-        '''
+#    def sin(self, i=False):
+#        '''
+#
+#Take the trigonometric sine of the data array and bounds in place.
+#
+#Units are accounted for in the calculation. For example, the the sine
+#of 90 degrees_east is 1.0, as is the sine of 1.57079632 radians. If
+#the units are not equivalent to radians (such as Kelvin) then they are
+#treated as if they were radians.
+#
+#The Units are changed to '1' (nondimensionsal).
+#
+#.. versionadded:: 2.0 
+#
+#:Parameters:
+#
+#    {+i}
+#
+#:Returns:
+#
+#    out : cf.{+Variable}
+#
+#:Examples:
+#
+#>>> c.Units
+#<CF Units: degrees_north>
+#>>> print c.array
+#[[-90 0 90 --]]
+#>>> c.sin()
+#>>> c.Units
+#<CF Units: 1>
+#>>> print c.array
+#[[-1.0 0.0 1.0 --]]
+#
+#>>> c.Units
+#<CF Units: m s-1>
+#>>> print c.array
+#[[1 2 3 --]]
+#>>> c.sin()
+#>>> c.Units
+#<CF Units: 1>
+#>>> print c.array
+#[[0.841470984808 0.909297426826 0.14112000806 --]]
+#
+#'''
+#        if i:
+#            c = self
+#        else:
+#            c = self.copy()
+#
+#        super(BoundedVariable, c).sin(i=True)
+#
+#        if c._hasbounds:
+#            c.bounds.sin(i=True)
+#
+#        return c
+#    #--- End: def
 
-Take the trigonometric sine of the data array and bounds in place.
-
-Units are accounted for in the calculation. For example, the the sine
-of 90 degrees_east is 1.0, as is the sine of 1.57079632 radians. If
-the units are not equivalent to radians (such as Kelvin) then they are
-treated as if they were radians.
-
-The Units are changed to '1' (nondimensionsal).
-
-.. versionadded:: 2.0 
-
-:Parameters:
-
-    {+i}
-
-:Returns:
-
-    out : cf.{+Variable}
-
-:Examples:
-
->>> c.Units
-<CF Units: degrees_north>
->>> print c.array
-[[-90 0 90 --]]
->>> c.sin()
->>> c.Units
-<CF Units: 1>
->>> print c.array
-[[-1.0 0.0 1.0 --]]
-
->>> c.Units
-<CF Units: m s-1>
->>> print c.array
-[[1 2 3 --]]
->>> c.sin()
->>> c.Units
-<CF Units: 1>
->>> print c.array
-[[0.841470984808 0.909297426826 0.14112000806 --]]
-
-'''
-        if i:
-            c = self
-        else:
-            c = self.copy()
-
-        super(BoundedVariable, c).sin(i=True)
-
-        if c._hasbounds:
-            c.bounds.sin(i=True)
-
-        return c
-    #--- End: def
-
-    def log(self, base=10, i=False):
-        '''
-
-Take the logarithm the data array and bounds element-wise.
-
-.. versionadded:: 2.0 
-
-:Parameters:
-
-    base : number, optional
-    
-    {+i}
-
-:Returns:
-
-    out : cf.{+Variable}
-
-'''
-        if i:
-            c = self
-        else:
-            c = self.copy()
-
-        super(BoundedVariable, c).log(base, i=True)
-
-        if c._hasbounds:
-            c.bounds.log(base, i=True)
-
-        return c
-    #--- End: def
-
-    def squeeze(self, axes=None, i=False):
-        '''
-
-Remove size 1 dimensions from the data array and bounds in place.
-
-.. versionadded:: 2.0 
-
-.. seealso:: `expand_dims`, `flip`, `transpose`
-
-:Parameters:
-
-    axes : (sequence of) int, optional
-        The size 1 axes to remove. By default, all size 1 axes are
-        removed. Size 1 axes for removal may be identified by the
-        integer positions of dimensions in the data array.
-
-    {+i}
-
-:Returns:
-
-    out : cf.{+Variable}
-
-:Examples:
-
->>> c.squeeze()
->>> c.squeeze(1)
->>> c.squeeze([1, 2])
-
-'''
-        c = super(BoundedVariable, self).squeeze(axes, i=i)
-
-        if c._hasbounds and c.bounds._hasData:
-            # Squeeze the bounds
-            axes = self._parse_axes(axes)
-            c.bounds.squeeze(axes, i=True)
-
-        return c
-    #--- End: def
+#    def log(self, base=10, i=False):
+#        '''
+#
+#Take the logarithm the data array and bounds element-wise.
+#
+#.. versionadded:: 2.0 
+#
+#:Parameters:
+#
+#    base : number, optional
+#    
+#    {+i}
+#
+#:Returns:
+#
+#    out : cf.{+Variable}
+#
+#'''
+#        if i:
+#            c = self
+#        else:
+#            c = self.copy()
+#
+#        super(BoundedVariable, c).log(base, i=True)
+#
+#        if c._hasbounds:
+#            c.bounds.log(base, i=True)
+#
+#        return c
+#    #--- End: def
+#
+#    def squeeze(self, axes=None, i=False):
+#        '''
+#
+#Remove size 1 dimensions from the data array and bounds in place.
+#
+#.. versionadded:: 2.0 
+#
+#.. seealso:: `expand_dims`, `flip`, `transpose`
+#
+#:Parameters:
+#
+#    axes : (sequence of) int, optional
+#        The size 1 axes to remove. By default, all size 1 axes are
+#        removed. Size 1 axes for removal may be identified by the
+#        integer positions of dimensions in the data array.
+#
+#    {+i}
+#
+#:Returns:
+#
+#    out : cf.{+Variable}
+#
+#:Examples:
+#
+#>>> c.squeeze()
+#>>> c.squeeze(1)
+#>>> c.squeeze([1, 2])
+#
+#'''
+#        c = super(BoundedVariable, self).squeeze(axes, i=i)
+#
+#        if c._hasbounds and c.bounds._hasData:
+#            # Squeeze the bounds
+#            axes = self._parse_axes(axes)
+#            c.bounds.squeeze(axes, i=True)
+#
+#        return c
+#    #--- End: def
 
     def transpose(self, axes=None, i=False):
-        '''
-
-Permute the dimensions of the data array and bounds in place.
+        '''Permute the dimensions of the data.
 
 .. versionadded:: 2.0 
 
@@ -1963,10 +2020,10 @@ Permute the dimensions of the data array and bounds in place.
 
 >>> c.ndim
 3
->>> c.transpose()
->>> c.transpose([1, 2, 0])
+>>> c.{+name}()
+>>> c.{+name}([1, 2, 0])
 
-'''
+        '''
         c = super(BoundedVariable, self).transpose(axes, i=i)
 
         ndim = c.ndim
@@ -2144,8 +2201,6 @@ class SubspaceBoundedVariable(SubspaceVariable):
 x.__getitem__(indices) <==> x[indices]
 
 '''
-        print "DEPRECATION WARNING: v.subspace[indices] has been deprecated. Use v[indices] instead."
-
         variable = self.variable
 
         if indices is Ellipsis:
@@ -2204,7 +2259,6 @@ x.__getitem__(indices) <==> x[indices]
             if bounds._hasData:
                 findices = list(findices)
                 if variable_data.ndim <= 1:
-#                    indices = list(indices)
                     index = indices[0]
                     if isinstance(index, slice):
                         if index.step < 0:
