@@ -33,7 +33,7 @@ from .filearray import FileArray, _TempFileArray #, SharedMemoryArray, _shared_m
 _Units_conform = Units.conform
 
 _dtype_object = numpy_dtype(object)
-
+#fm = FREE_MEMORY()
 # --------------------------------------------------------------------
 # Set of partitions' temporary files
 #
@@ -49,24 +49,30 @@ def _remove_temporary_files(filename=None):
 
 The removed files' names are deleted from the _temporary_files set.
 
-It is intended to delete individual files as part of the garbage
+The intended use is to delete individual files as part of the garbage
 collection process and to delete all files when python exits.
 
 This is quite brutal and may break partitions if used unwisely. It is
 not recommended to be used as a general tidy-up function.
 
+.. seealso:: `__del__`
+
+:Examples 1:
+
+>>> _remove_temporary_files()
+
 :Parameters:
 
-    filename : str, optional
+    filename: `str`, optional
         The name of file to remove. The file name must be in the
-        _temporary_files set. By default all files given in the
+        _temporary_files set. By default all files named in the
         _temporary_files set are removed.
 
 :Returns:
 
-    None
+    `None`
 
-:Examples:
+:Examples 2:
 
 >>> _temporary_files
 set(['/tmp/cf_array_B8SSw2.npy',
@@ -127,10 +133,17 @@ class Partition(object):
 
 A partition of a master data array.
 
-The partition spans all or part of exactly one sub-array of the master
+The partition spans all or part of exactly one subarray of the master
 data array
 
 '''
+
+    # Counters for the number of partitions pointing to each open
+    # file.  A file is only closed when the count reaches zero for
+    # that file.  The key is the absolute path to the file. The
+    # corresponding value is the counter.
+    file_counter = {}
+
     def __init__(self, subarray=None, flip=None, location=None,
                  shape=None, Units=None, part=None, axes=None,
                  fill=None):
@@ -141,7 +154,7 @@ data array
 :Parameters:
 
     subarray : numpy array-like, optional
-        The sub-array for the partition. Must be a numpy array or any
+        The subarray for the partition. Must be a numpy array or any
         array storing object with a similar interface. DO NOT UPDATE
         INPLACE.
 
@@ -150,13 +163,13 @@ data array
         array. DO NOT UPDATE INPLACE.
 
     axes : list, optional
-        The identities of the axes of the partition's sub-array. If
-        the partition's sub-array a scalar array then it is an empty
+        The identities of the axes of the partition's subarray. If
+        the partition's subarray a scalar array then it is an empty
         list. DO NOT UPDATE INPLACE.
 
     part : list, optional
-        The part of the partition's sub-array which comprises its data
-        array. If the partition's data array is to the whole sub-array
+        The part of the partition's subarray which comprises its data
+        array. If the partition's data array is to the whole subarray
         then *part* may be an empty list. DO NOT UPDATE INPLACE.
 
     shape : list, optional
@@ -166,7 +179,7 @@ data array
         from *location*. DO NOT UPDATE INPLACE.
 
     Units : Units, optional
-        The units of the partition's sub-array. DO NOT UPDATE INPLACE.
+        The units of the partition's subarray. DO NOT UPDATE INPLACE.
 
 :Examples:
 
@@ -196,7 +209,7 @@ data array
         self.location  = location  # DO NOT UPDATE INPLACE
         self.shape     = shape     # DO NOT UPDATE INPLACE
         self.Units     = Units     # DO NOT UPDATE INPLACE
-        self._subarray = subarray  # DO NOT UPDATE INPLACE
+        self.subarray  = subarray  # DO NOT UPDATE INPLACE
         self.fill      = fill      # DO NOT UPDATE INPLACE
   
         if shape is None and location is not None:
@@ -225,11 +238,16 @@ any other partition then the temporary file is removed from disk.
 If the partition contains a non-temporary file which is not referenced
 by any other partition then the file is closed.
 
-'''     
+        '''
+        self._decrement_file_counter()
+
         subarray = getattr(self, '_subarray', None)
 
-        if getrefcount is not None:
-            if subarray is None or getrefcount(subarray) > 2:
+        # If the subarray is unique it will have 2 references to
+        # it plus 1 within this method, making 3. If it has more
+        # than 3 references to it then it is not unique.
+        if getrefcount is not None:            
+            if subarray is None or getrefcount(subarray) > 3:
                 return
         else:
             # getrefcount has itself been deleted or is in the process
@@ -243,12 +261,19 @@ by any other partition then the file is closed.
             # from disk.
             _remove_temporary_files(_partition_file)
 
-        elif (numpy_ndarray is not None and 
-              not isinstance(subarray, numpy_ndarray)):
+#        elif (numpy_ndarray is not None and 
+#              not isinstance(subarray, numpy_ndarray)):
+#            # This partition contains a non-temporary file which is
+#            # not referenced by any other partition, so close the
+#            # file.
+        elif (FileArray is not None and isinstance(subarray, FileArray)):
             # This partition contains a non-temporary file which is
             # not referenced by any other partition, so close the
-            # file.
-            subarray.close()           
+            # file if the count of partitions pointing to it is 0.
+            count = Partition.file_counter.get(subarray.file, None)
+            if count is not None and count <= 0:
+                subarray.close()
+            #--- End: if
     #--- End: def
 
 #    def __getstate__(self):
@@ -300,6 +325,53 @@ x.__str__() <==> str(x)
         return '%s: %s' % (self.__class__.__name__, self.__dict__)
     #--- End: def
 
+    def _add_to_file_counter(self, i):
+        '''Add i to the Partition.file_counter if self._subarray is an
+instance of FileArray and not a temporary FileArray.
+
+:Parameters:
+
+    i: `int`
+
+:Returns:
+
+    `None`
+
+        '''
+        if hasattr(self, '_subarray'):
+            subarray = self._subarray
+            if (not isinstance(subarray, _TempFileArray) and
+                isinstance(subarray, FileArray)):
+                filename = subarray.file
+                if filename is not None:
+                    count = Partition.file_counter.get(filename, 0)
+                    Partition.file_counter[filename] = count + i
+    #--- End: def
+
+    def _increment_file_counter(self):
+        '''Add 1 to the Partition.file_counter if self._subarray is an
+instance of FileArray and not a temporary FileArray.
+
+:Returns:
+
+    `None`
+
+        '''
+        self._add_to_file_counter(1)
+    #--- End: def
+
+    def _decrement_file_counter(self):
+        '''Subtract 1 from the Partition.file_counter if self._subarray is an
+instance of FileArray and not a temporary FileArray.
+
+:Returns:
+
+    `None`
+
+        '''
+        self._add_to_file_counter(-1)
+    #--- End: def
+
     def _configure_auxiliary_mask(self, auxiliary_mask):
         '''Add the auxiliary mask to the config dictionary.
 
@@ -369,7 +441,7 @@ data array.
     def in_memory(self):
         '''
 
-True if and only if the partition's sub-array is in memory as opposed
+True if and only if the partition's subarray is in memory as opposed
 to on disk.
 
 :Examples:
@@ -385,7 +457,7 @@ False
 #    def in_shared_memory(self):
 #        '''
 #
-#True if and only if the partition's sub-array is a shared memory array.
+#True if and only if the partition's subarray is a shared memory array.
 #
 #.. seealso:: `array`, `in_memory`, `on_disk`, `to_shared_memory`
 #
@@ -406,7 +478,7 @@ False
     # ----------------------------------------------------------------
     @property
     def in_temporary_file(self):
-        '''True if and only if the partition's sub-array is on disk in a
+        '''True if and only if the partition's subarray is on disk in a
 temporary file.
 
 .. seealso:: `array`, `in_memory`, `in_shared_memory`, `on_disk`, `to_disk`
@@ -426,7 +498,7 @@ False
     def on_disk(self):
         '''
 
-True if and only if the partition's sub-array is on disk as opposed to
+True if and only if the partition's subarray is on disk as opposed to
 in memory.
 
 :Examples:
@@ -438,7 +510,7 @@ True
 False
 
 '''
-        return not isinstance(self._subarray, FileArray)
+        return isinstance(self._subarray, FileArray)
     #--- End: if
 
     # ----------------------------------------------------------------
@@ -446,7 +518,7 @@ False
     # ----------------------------------------------------------------
     @property
     def in_file(self):
-        '''True if and only if the partition's sub-array is on disk as opposed to
+        '''True if and only if the partition's subarray is on disk as opposed to
 in memory.
 
 :Examples:
@@ -548,11 +620,14 @@ Number of elements in the partition's data array (not its subarray).
     #--- End: def
     @subarray.setter
     def subarray(self, value):
+        self._decrement_file_counter()
         self._subarray = value
+        self._increment_file_counter()
         self._in_place_changes = False
     #--- End: def
     @subarray.deleter
     def subarray(self):
+        self._decrement_file_counter()
         self._subarray = None
         self._in_place_changes = True
     #--- End: def
@@ -564,7 +639,7 @@ Number of elements in the partition's data array (not its subarray).
 #    def subarray_in_external_file(self):
 #        '''
 #
-#True if and only if the partition's sub-array is in an external file.
+#True if and only if the partition's subarray is in an external file.
 #
 #:Examples:
 #
@@ -654,15 +729,20 @@ values of the partition's `!_original` attribute and on the
 >>> p.array(...)
 >>> p.close()
 
-        '''     
-        config = self.config
+        '''
+        config = getattr(self, 'config', None)
+        
+        if config is None:
+            return
+        
         if kwargs:
             config.update(kwargs)
 
-        _debug = False #True
+        _debug = False
 
         original = getattr(self, '_original', None)
-        if _debug:  print 'Partition.close: original =', original
+        if _debug:
+            print 'Partition.close: original =', original
         
         if not original:
             originally_on_disk = False
@@ -672,26 +752,30 @@ values of the partition's `!_original` attribute and on the
             original_subarray  = original._subarray
             
         config = self.config
-        if _debug:  print 'Partition.close: config =',config
+        if _debug:
+            print 'Partition.close: config =',config
 
         if config['serial']:
             # --------------------------------------------------------
             # SERIAL
             # --------------------------------------------------------
-            if _debug: print 'Partition.close: serial'
+            if _debug:
+                print 'Partition.close: serial'
             if config['readonly']:
                 if originally_on_disk:
                     if config.get('to_disk', False):
                         # 1.1.1.1 Original subarray was on disk and we
                         #         don't want to keep the current
                         #         subarray
-                        if _debug: print 'Partition.close: 1.1.1.1 revert'
+                        if _debug:
+                            print 'Partition.close: 1.1.1.1 revert'
                         self.revert()
                     elif FREE_MEMORY() <= FM_THRESHOLD():
                         # 1.1.1.2 Original subarray was on disk but
                         #         there is not enough memory to keep
                         #         the current subarray
-                        if _debug: print 'Partition.close: 1.1.1.2 revert'
+                        if _debug:
+                            print 'Partition.close: 1.1.1.2 revert ({} <= {})'.format(FREE_MEMORY(), FM_THRESHOLD())
                         self.revert()
                     else:
                         # 1.1.1.3 Original subarray was on disk and
@@ -702,31 +786,36 @@ values of the partition's `!_original` attribute and on the
                             # Original subarray was a temporary file
                             # on disk which is not referenced by any
                             # other partitions
-                            _remove_temporary_file(original_subarray._partition_file)
+                            _remove_temporary_files(original_subarray._partition_file)
 
-                        if _debug: print 'Partition.close: 1.1.1.3 pass'
+                        if _debug:
+                            print 'Partition.close: 1.1.1.3 del masked ({} > {})'.format(FREE_MEMORY(), FM_THRESHOLD())
                         del self.masked       
                         pass
 
                 else:
-                    if _debug: print 'Partition.close: originally in memory'
+                    if _debug:
+                        print 'Partition.close: subarray originally in memory'
                     if config.get('to_disk', False):
                         # 1.1.2.1 Original subarray was in memory and
                         #         we don't want to keep the current
                         #         subarray in memory
-                        if _debug: print 'Partition.close: 1.1.2.1 to_disk'
+                        if _debug:
+                            print 'Partition.close: 1.1.2.1 to_disk'
                         self.to_disk(reopen=False)
                     elif FREE_MEMORY() <= FM_THRESHOLD():
-                        # 1.1.2.3 Original subarray was in memory and
+                        # 1.1.2.2 Original subarray was in memory and
                         #         unique but there is not enough
                         #         memory to keep the current subarray
-                        if _debug: print 'Partition.close: 1.1.2.2 to_disk'
+                        if _debug:
+                            print 'Partition.close: 1.1.2.2 to_disk'
                         self.to_disk(reopen=False)
                     else:
                         # 1.1.2.3 Original subarray was in memory and
                         #         unique and there is enough memory to
                         #         keep the current subarray in memory
-                        if _debug: print 'Partition.close: 1.1.2.3 pass'
+                        if _debug:
+                            print 'Partition.close: 1.1.2.3 pass'
                         pass
             else:
                 # config['readonly'] is False
@@ -740,7 +829,7 @@ values of the partition's `!_original` attribute and on the
                             # Original subarray was a temporary file
                             # on disk which is not referenced by any
                             # other partitions
-                            _remove_temporary_file(original_subarray._partition_file)
+                            _remove_temporary_files(original_subarray._partition_file)
 
                         if _debug: print 'Partition.close: 1.2.1.1 to_disk'
                         self.to_disk(reopen=False)
@@ -753,7 +842,7 @@ values of the partition's `!_original` attribute and on the
                             # Original subarray was a temporary file
                             # on disk which is not referenced by any
                             # other partitions
-                            _remove_temporary_file(original_subarray._partition_file)
+                            _remove_temporary_files(original_subarray._partition_file)
 
                         if _debug: print 'Partition.close: 1.2.1.2 to_disk'
                         self.to_disk(reopen=False)
@@ -789,8 +878,8 @@ values of the partition's `!_original` attribute and on the
             pass
         #--- End: if
 
-        if hasattr(self, '_original'):
-            del self._original
+#        if hasattr(self, '_original'):
+#            del self._original
 
         del self.config
     #--- End: def
@@ -815,6 +904,8 @@ Return a deep copy.
         new = Partition.__new__(Partition)
         new.__dict__ = self.__dict__.copy()
 
+        self._increment_file_counter()
+        
         return new
     #--- End: def
 
@@ -870,7 +961,7 @@ otherwise a memory leak could occur. For example:
 
         if not self.in_memory:
             # --------------------------------------------------------
-            # The sub-array is not in memory.
+            # The subarray is not in memory.
             #
             # It could be in a file on disk or implied by a FileArray
             # object, etc.
@@ -894,7 +985,7 @@ otherwise a memory leak could occur. For example:
             in_place_changes = False
         else:
             # --------------------------------------------------------
-            # The sub-array is in memory
+            # The subarray is in memory
             # --------------------------------------------------------
             update = config['update']
 
@@ -914,7 +1005,7 @@ otherwise a memory leak could occur. For example:
 
         if not p_data.ndim and isinstance(p_data, (numpy_number, numpy_bool_)):
             # --------------------------------------------------------
-            # p_data is a numby number (like numpy.int64) which does
+            # p_data is a numpy number (like numpy.int64) which does
             # not support assignment, so convert it to a numpy array.
             # --------------------------------------------------------
             p_data = numpy_array(p_data)
@@ -942,7 +1033,7 @@ otherwise a memory leak could occur. For example:
         #--- End: if
 
         self.masked = masked
-        
+
         # ------------------------------------------------------------
         # Make sure that the data array has the correct units. This
         # process will deep copy the data array if required (e.g. if
@@ -959,7 +1050,7 @@ otherwise a memory leak could occur. For example:
             inplace = not copy
             p_data  = func(p_data, p_units, units, inplace)
             p_units = units
-
+            
             if not inplace:
                 # We've just copied p_data, so in place changes are
                 # not possible
@@ -1074,7 +1165,7 @@ otherwise a memory leak could occur. For example:
         # Update the partition
         # ------------------------------------------------------------
         if update:
-            self._subarray = p_data ##?? DCH CHECK
+            self.subarray  = p_data ##?? DCH CHECK
             self.Units     = p_units
             self.part      = []
             self.axes      = axes
@@ -1092,7 +1183,6 @@ otherwise a memory leak could occur. For example:
         # ------------------------------------------------------------
         # Return the numpy array
         # ------------------------------------------------------------
-#        print 'self.masked =', self.masked
         return p_data
     #--- End: def
     
@@ -1118,7 +1208,7 @@ True
     def file_close(self):
         '''
 
-Close all file containing the sub-array, if there is one.
+Close all file containing the subarray, if there is one.
 
 :Returns:
 
@@ -1428,13 +1518,13 @@ array.
         '''
         if not self.in_memory:
             # --------------------------------------------------------
-            # The sub-array is on disk so getting the partition's data
+            # The subarray is on disk so getting the partition's data
             # array will require extra memory
             # --------------------------------------------------------
             extra_memory = True
         else:
             # --------------------------------------------------------
-            # The sub-array is already in memory
+            # The subarray is already in memory
             # --------------------------------------------------------
             config = self.config
 
@@ -1523,24 +1613,22 @@ array.
     #--- End: def
 
     def overlaps(self, indices):
-        '''
-    
-Return True if the sub-array overlaps a subspace of the master array.
+        '''Return True if the subarray overlaps a subspace of the master array.
 
 :Parameters:
 
-   indices : sequence
+   indices: sequence
        Indices describing a subset of the master array. Each index is
-       either a slice object or a list. If the sequence is empty then
-       it is assumed that the master array is a scalar array.
+       either a `slice` object or a `list`. If the sequence is empty
+       then it is assumed that the master array is a scalar array.
 
 :Returns:
 
-    p_indices, shape : list, list or None, None
+    p_indices, shape : `list`, `list` or `None`, `None`
         If the partition overlaps the *indices* then return a list of
         indices which will subset the partition's data to where it
         overlaps the master indices and the subsetted partition's
-        shape as a list. Otherwise return `None, None`.
+        shape as a list. Otherwise return `None`, `None`.
 
 :Examples:
 
@@ -1548,7 +1636,7 @@ Return True if the sub-array overlaps a subspace of the master array.
 >>> p.overlaps(indices)
 (slice(), ddfsfsd), [3, 5, 4]
 
-'''
+        '''
         p_indices = []
         shape     = []
         
@@ -1631,9 +1719,9 @@ Return True if the sub-array overlaps a subspace of the master array.
 #    #--- End: def
     
     def to_disk(self, reopen=True):
-        '''Move the partition's sub-array to a temporary file on disk.
+        '''Move the partition's subarray to a temporary file on disk.
 
-.. note:: It is assumed that the partition's sub-array is currently in
+.. note:: It is assumed that the partition's subarray is currently in
 memory, but this is not checked.
 
 :Parameters:
@@ -1643,7 +1731,7 @@ memory, but this is not checked.
 :Returns:
 
     out: `bool`
-        True if the sub-array was moved to disk, False otherwise.
+        True if the subarray was moved to disk, False otherwise.
 
 :Examples:
 
@@ -1656,7 +1744,7 @@ memory, but this is not checked.
         except:
             return False
 
-        self._subarray = tfa
+        self.subarray = tfa
         _temporary_files.add(tfa._partition_file)
 
         if reopen:
@@ -1676,7 +1764,7 @@ memory, but this is not checked.
 #:Returns:
 #
 #    out : bool
-#        Whether or not the sub-array is in shared memory.
+#        Whether or not the subarray is in shared memory.
 #
 #'''
 #        if self.in_shared_memory:
@@ -1691,7 +1779,7 @@ memory, but this is not checked.
 #            return False
 #
 #        try:
-#            self._subarray = SharedMemoryArray(self.array)
+#            self.subarray = SharedMemoryArray(self.array)
 #        except:
 #            return False
 #
@@ -1711,15 +1799,15 @@ The updated partition is always dependent of the other partition.
 
 :Parameters:
 
-    other : Partition
+    other: `Partition`
 
 :Returns:
 
-    None
+    `None`
 
 :Examples:
 
->>> p.is_partition(q)
+>>> p.revert()
 
 '''
         original = getattr(self, '_original', None)
@@ -1731,9 +1819,9 @@ The updated partition is always dependent of the other partition.
             keep_output = True
         else:
             keep_output = False
-        
+
         del self._original
-        
+
         self.__dict__ = original.__dict__
         
         if keep_output:
