@@ -25,10 +25,13 @@ to the order of the elements.
 Attribute  Type     Description
 =========  =======  ==================================================
 `!size`    `int`    The size of the domain axis.
+
+`!ncdim`   `str`    The name of this domain axis as a netCDF
+                    dimension.
 =========  =======  ==================================================
 
     '''
-    def __init__(self, size=None):
+    def __init__(self, size=None, ncdim=None):
         '''**Initialization**
 
 :Parameters:
@@ -36,8 +39,12 @@ Attribute  Type     Description
     size: `int`, optional
         The size of the domain axis.
 
+    ncdim: `str`, optional
+        The name of this domain axis as a netCDF dimension.
+
         '''
-        self.size = size
+        self.size  = size
+        self.ncdim = ncdim
     #--- End: def
 
     def __deepcopy__(self, memo):
