@@ -60,7 +60,7 @@ if _linux:
     # GNU/LINUX
     # ----------------------------------------------------------------
     _meminfo_fields = set(('SReclaimable:', 'Cached:', 'Buffers:', 'MemFree:'))
-    _meminfo_file   = open('/proc/meminfo', 'r', 1)
+#    _meminfo_file   = open('/proc/meminfo', 'r', 1)
 
     def _free_memory():
         '''
@@ -91,7 +91,7 @@ longer required.
         # ----------------------------------------------------------------
         free_KiB = 0.0
         n=0
-    
+        _meminfo_file   = open('/proc/meminfo', 'r', 1)
         for line in _meminfo_file:
             field_size = line.split()
             if field_size[0] in _meminfo_fields:
@@ -100,8 +100,9 @@ longer required.
                 if n > 3:
                     break
         #--- End: for
-        _meminfo_file.seek(0)
-    
+#        _meminfo_file.seek(0)
+        del _meminfo_file
+
         return free_KiB * 1024
     #--- End: def
 else:
@@ -882,12 +883,15 @@ False
 >>> cf._numpy_allclose(a, b)
 True
 
-'''      
+'''
+
+    # THIS IS WHERE SOME NUMPY FUTURE WARNINGS ARE COMING FROM
+    
     a_is_masked = numpy_ma_isMA(a)
     b_is_masked = numpy_ma_isMA(b)
     
     if not (a_is_masked or b_is_masked):
-        try:
+        try:            
             return numpy_allclose(a, b, rtol=rtol, atol=atol)
         except (IndexError, NotImplementedError, TypeError):
             return numpy_all(a == b)
