@@ -248,7 +248,7 @@ ancillaries, field ancillaries).
     nc_dimensions = map(str, nc.dimensions)
     if _debug:
         print 'nc_dimensions =', nc_dimensions
-        
+
     sample_ncdimension   = None
     instance_ncdimension = None
         
@@ -440,10 +440,10 @@ ancillaries, field ancillaries).
     # data variable and the relevant shared metadata.
     # ----------------------------------------------------------------
     if _debug:
-        print 'Data variables which will become fields:'
+        print 'Data variables that will become fields:'
         for ncvar in variables:
             print '   ', ncvar
-    
+
     domain_ancillaries    = {}
     field_ancillaries     = {}
     dimension_coordinates = {}
@@ -477,63 +477,6 @@ ancillaries, field ancillaries).
         fields_in_file.append(f)
     #--- End: for
 
-#    ncvar_to_field = {}
-#    if coordref_parameters:
-#        i = 0        
-#        while i < len(fields_in_file):
-#            f = fields_in_file[i]
-#            ncvar = f.ncvar            
-#            if ncvar in coordref_parameters:
-#                # Map the pointer to the field so that later we'll be
-#                # able to replace the pointer with the field
-#                if ncvar not in ncvar_to_field:
-#                    ncvar_to_field[ncvar] = f
-#
-#                del fields_in_file[i]
-#                i -= 1
-#            #--- End: if
-#
-#            i += 1
-#    #--- End: if
-#
-#    # ----------------------------------------------------------------
-#    # Inside coordinate references, replace parameter nc variables
-#    # with Data objects
-#    # ----------------------------------------------------------------
-#    if ncvar_to_field:
-#        for f in fields_in_file:
-#            for ref in f.refs().values():
-#                for term, value in ref.parameter_terms.items():
-#                    try:
-#                        ref[term] = ncvar_to_field[value].Data.copy()
-#                    except (KeyError, AttributeError):
-#                        ref[term] = None
-#    #--- End: if
-        
-#    # ----------------------------------------------------------------
-#    # Get rid of any rogue fields
-#    # ----------------------------------------------------------------
-#    if rogue_fields:
-#        i = 0
-#        while rogue_fields:
-#            try:
-#                f = fields_in_file[i]
-#            except IndexError:
-#                # No more fields
-#                break
-#            
-#            ncvar = f.ncvar            
-#            if ncvar in rogue_fields:
-#                # Get rid of this field
-#                rogue_fields.discard(ncvar)
-#                del fields_in_file[i]
-#                i -= 1 
-#            #--- End: if
-#
-#            i += 1
-#        #--- End: while
-#    #--- End: if
-
     return fields_in_file
 #--- End: def
 
@@ -566,13 +509,22 @@ def _parse_DSG_contiguous_compression(nc, ncvar, attributes,
     if _debug:
         print '    DSG count variable: sample_dimension =', sample_ncdimension
 
+    filename = nc.filepath()
+    
     compression_type = _compression_type['DSG_contiguous']
 
     variable = nc[ncvar]
     instance_ncdimension    = variable.dimensions[0]
     instance_dimension_size = variable.size
 
-    count_array = _create_Variable(nc, ncvar, attributes, uncompress=False, g=g).array
+    count = _create_Variable(nc, ncvar, attributes, uncompress=False, g=g)
+    count_array = count.array
+
+    del count
+    if not nc.isopen():
+        # Re-read the netCDF file if it has been closed during the
+        # deletion of count
+        nc = _open_netcdf_file(filename, 'r')
 
     element_dimension_size = count_array.max()
 
@@ -656,12 +608,21 @@ def _parse_DSG_indexed_compression(nc, ncvar, attributes,
     if _debug:
         print '    DSG index variable: instance_dimension =', instance_ncdimension
 
+    filename = nc.filepath()
+    
     compression_type = _compression_type['DSG_indexed']
 
     instance_dimension_size = nc.dimensions[instance_ncdimension].size
     
-    index_array = _create_Variable(nc, ncvar, attributes, uncompress=False, g=g).array
+    index = _create_Variable(nc, ncvar, attributes, uncompress=False, g=g)
+    index_array = index.array
     
+    del index
+    if not nc.isopen():
+        # Re-read the netCDF file if it has been closed during the
+        # deletion of index
+        nc = _open_netcdf_file(filename, 'r')
+
     (instances, inverse, counts) = numpy_unique(index_array,
                                                 return_inverse=True,
                                                 return_counts=True)
@@ -972,7 +933,7 @@ Create a field for a given netCDF variable.
             #--- End: if
             
             if _debug:
-                print '    Inserting dimension coordinate:', repr(coord)
+                print '    Inserting', repr(coord)
             dim = f.insert_dim(coord, copy=False)
             # Record the netCDF dimension name for this axis
 #            f.Axes[dim].ncdim = ncdim
@@ -994,7 +955,7 @@ Create a field for a given netCDF variable.
 
             axis = DomainAxis(size)
             if _debug:
-                print '    Inserting axis:', repr(axis)
+                print '    Inserting', repr(axis)
             dim = f.insert_axis(axis)
             # Record the netCDF dimension name for this axis
 #            f.Axes[dim].ncdim = ncdim
@@ -1067,7 +1028,7 @@ Create a field for a given netCDF variable.
                     # construct.
                     axis = DomainAxis(1)
                     if _debug:
-                        print '    Inserting axis:', repr(axis)
+                        print '    Inserting', repr(axis)
                     dim = f.insert_axis(axis)
                     # Record the netCDF dimension name for this axis
 #                    f.Axes[dim].ncdim = ncdim                    
@@ -1082,7 +1043,7 @@ Create a field for a given netCDF variable.
                 # Insert dimension coordinate
                 coord = coord.asdimension(copy=False)
                 if _debug:
-                    print '    Inserting dimension coordinate:', repr(coord)
+                    print '    Inserting', repr(coord)
                 dim = f.insert_dim(coord, copy=False)
                 # Record the netCDF dimension name for this axis
 #                f.Axes[dim].ncdim = ncvar
@@ -1094,7 +1055,7 @@ Create a field for a given netCDF variable.
             else:
                 # Insert auxiliary coordinate
                 if _debug:
-                    print '    Inserting auxiliary coordinate:', repr(coord)
+                    print '    Inserting', repr(coord)
                 aux = f.insert_aux(coord, axes=dimensions, copy=False)
                 ncvar_to_key[ncvar] = aux
             
