@@ -39,7 +39,7 @@ class NetCDFError(Exception):
     '''A runtime netCDF error'''
     pass
 
-def write(fields, filename, fmt='NETCDF3_CLASSIC', overwrite=True,
+def write(fields, filename, fmt='NETCDF4', overwrite=True,
           verbose=False, cfa_options=None, mode='w',
           least_significant_digit=None, endian='native', compress=0,
           fletcher32=False, no_shuffle=False, datatype=None,
