@@ -21,35 +21,31 @@ def read(files, verbose=False, ignore_read_error=False,
          follow_symlinks=False, um=None, chunk=True, _debug=False):
     '''Read fields from netCDF, PP or UM fields files.
 
-A file may be on disk or on a OPeNDAP server.
+Files may be on disk or on a OPeNDAP server.
 
 Any amount of any combination of CF-netCDF and CFA-netCDF files (or
 URLs if DAP access is enabled), Met Office (UK) PP files and Met
 Office (UK) fields files format files may be read.
 
-**netCDF files**
-   * The netCDF variable names of the field and its components are
-     stored in their `!ncvar` attributes.
-   
-   * Fields referenced within coordinate reference or ancillary
-     variables objects are not included in the returned list of
-     fields.
-
-**PP and fields files**
+**Notes for PP and UM fields files**
    * The *aggregate* option ``'relaxed_units'`` is set to True for all
      input files.
     
    * STASH code to standard conversion uses the table in
      ``cf/etc/STASH_to_CF.txt``.
 
-**Files on OPeNDAP servers**
+**Notes for files on OPeNDAP servers**
    * All files on OPeNDAP servers are assumed to be netCDF files.
 
-.. seealso:: `cf.write`
+.. seealso:: `cf.read_field`, `cf.write`
+
+:Examples 1:
+
+>>> f = cf.read('file.nc')
 
 :Parameters:
 
-    files : (arbitrarily nested sequence of) str
+    files: (arbitrarily nested sequence of) `str`
 
         A string or arbitrarily nested sequence of strings giving the
         file names or OPenDAP URLs from which to read fields. Various
@@ -89,12 +85,12 @@ Office (UK) fields files format files may be read.
     umversion:
         Deprecated. Use the *um* parameter instead.
 
-    ignore_read_error : bool, optional
+    ignore_read_error: `bool`, optional
         If True then ignore any file which raises an IOError whilst
         being read, as would be the case for an empty file, unknown
         file format, etc. By default the IOError is raised.
     
-    fmt : str, optional
+    fmt: `str`, optional
         Only read files of the given format, ignoring all other
         files. Valid formats are ``'NETCDF'`` for CF-netCDF files,
         ``'CFA'`` for CFA-netCDF files and ``'PP'`` for PP files and
@@ -102,7 +98,7 @@ Office (UK) fields files format files may be read.
         formats are read.  default files of any of these formats are
         read.
 
-    aggregate : bool or dict, optional
+    aggregate: `bool` or `dict`, optional
         If True (the default) or a (possibly empty) dictionary then
         aggregate the fields read in from all input files into as few
         fields as possible using the CF aggregation rules. If
@@ -110,18 +106,18 @@ Office (UK) fields files format files may be read.
         arguments to the `cf.aggregate` function. If False then the
         fields are not aggregated.
 
-    squeeze : bool, optional
+    squeeze: `bool`, optional
         If True then remove size 1 axes from each field's data array.
 
-    unsqueeze : bool, optional
+    unsqueeze: `bool`, optional
         If True then insert size 1 axes from each field's domain into
         its data array.
 
-    select, select_options : *optional*
+    select, select_options: optional
         Only return fields which satisfy the given conditions on their
         property values. Only fields which, prior to any aggregation,
-        satisfy ``f.match(select, **select_options) == True`` are
-        returned. See `cf.Field.match` for details.
+        satisfy ``f.match(description=select, **select_options) ==
+        True`` are returned. See `cf.Field.match` for details.
 
     field: (sequence of) `str`, optional
         Create independent fields from field components. The *field*
@@ -148,14 +144,14 @@ Office (UK) fields files format files may be read.
 
         .. versionadded:: 1.0.4
 
-    recursive : bool, optional
+    recursive: `bool`, optional
         If True then allow directories to be specified by the *files*
         parameter and recursively search the directories for files to
         read.
 
         .. versionadded:: 1.1.9
 
-    follow_symlinks : bool, optional
+    follow_symlinks: `bool`, optional
         If True, and *recursive* is True, then also search for files
         in directories which resolve to symbolic links. By default
         directories which resolve to symbolic links are
@@ -217,11 +213,10 @@ Office (UK) fields files format files may be read.
 
 :Returns:
     
-    out : cf.FieldList or cf.Field
-        A list of fields, or if there is only one field, the
-        individual field.
+    out: `cf.FieldList`
+        A list of the fields fpound in the input file(s).
 
-:Examples:
+:Examples 2:
 
 >>> f = cf.read('file*.nc')
 >>> f
@@ -404,25 +399,26 @@ Office (UK) fields files format files may be read.
     # 3) Nothing
     # ----------------------------------------------------------------
     if squeeze:
-        [f.squeeze(i=True) for f in field_list]
+        for f in field_list:
+            f.squeeze(i=True) 
     elif unsqueeze:
-        [f.unsqueeze(i=True) for f in field_list]
-
+        for f in field_list:
+            f.unsqueeze(i=True)
+            
     if nfields is not None and len(field_list) != nfields:
         raise ValueError(
-            "Error whilst reading file{}: {} field{} requested but {} fields found".format(
-    _plural(file_counter), nfields, _plural(nfields), len(field_list)))
-
-#    if len(field_list) == 1:
-#        # Return a field instead of a field list
-#        field_list = field_list[0]
+"{} field{} requested but {} fields found in file{}".format(
+    nfields, _plural(nfields), len(field_list), _plural(file_counter)))
 
     return field_list
 #--- End: def
 
 def read1(*args, **kwargs):
-    '''``f=cf.read1(*args, **kwargs)`` is equivalent to ``f=cf.read(*args,
-nfields=1, **kwargs)[0]``
+    '''Read a single field from netCDF, PP or UM fields files.
+
+.. versionadded:: 2.0
+
+.. seealso:: `cf.read`
 
     '''
     print "WARNING: Use cf.read_field in favour of cf.read1. cf.read1 will be deprecated at a later version"
@@ -431,8 +427,55 @@ nfields=1, **kwargs)[0]``
 
 
 def read_field(*args, **kwargs):
-    '''``f=cf.read_field(*args, **kwargs)`` is equivalent to ``f=cf.read(*args,
-nfields=1, **kwargs)[0]``
+    '''Read a single field from netCDF, PP or UM fields files.
+
+If more than one field is found in the input files then an error is
+raised. 
+
+`cf.read` should be used unless it is known that only one field will
+be created from the input file(s).
+
+Files may be on disk or on a OPeNDAP server.
+
+Any amount of any combination of CF-netCDF and CFA-netCDF files (or
+URLs if DAP access is enabled), Met Office (UK) PP files and Met
+Office (UK) fields files format files may be read.
+
+**Notes for PP and UM fields files**
+   * The *aggregate* option ``'relaxed_units'`` is set to True for all
+     input files.
+    
+   * STASH code to standard conversion uses the table in
+     ``cf/etc/STASH_to_CF.txt``.
+
+**Notes for files on OPeNDAP servers**
+   * All files on OPeNDAP servers are assumed to be netCDF files.
+
+Note that ``f=cf.read_field(*args, **kwargs)`` is equivalent to
+``f=cf.read(*args, nfields=1, **kwargs)[0]``.
+
+.. versionadded:: 2.0.3
+
+.. seealso:: `cf.read`, `cf.write`
+
+:Examples 1:
+
+>>> f = cf.read_field('file.nc')
+
+:Parameters:
+
+    args, kwargs: optional
+        Any arguments and keyword arguments accepted by `cf.read`.
+
+:Returns:
+
+    out `cf.Field`
+        The unique field from the input file(s).
+
+:Examples 2:
+
+>>> f = cf.read_field('file.nc')
+>>> f = cf.read_field('file[1-9].nc', select='air_temperature')
 
     '''
     kwargs['nfields'] = 1
@@ -441,6 +484,9 @@ nfields=1, **kwargs)[0]``
 
 
 def _plural(n):
+    '''Return a suffix which reflects a word's plural.
+
+    '''
     return 's' if n !=1 else ''
 
 def _read_a_file(filename,
@@ -460,10 +506,10 @@ Read the contents of a single file into a field list.
 
 :Parameters:
 
-    filename : str
+    filename: `str`
         The file name.
 
-    aggregate_options : dict, optional
+    aggregate_options: `dict`, optional
         The keys and values of this dictionary may be passed as
         keyword parameters to an external call of the aggregate
         function.
