@@ -5,6 +5,7 @@ import inspect
 
 import numpy
 from scipy.ndimage import convolve1d
+from scipy.signal import get_window
 
 import cf
 
@@ -17,12 +18,13 @@ class MathTest(unittest.TestCase):
     
     test_only = []
 #    test_only = ('NOTHING!!!!!',)
-#    test_only = ('test_Field_filter')
+#    test_only = ('test_Field_convolution_filter')
 #    test_only = ('test_Field_derivative')
 #    test_only = ('test_relative_vorticity_distance')
 #    test_only = ('test_relative_vorticity_latlong')
 
-    def test_Field_filter(self):
+    def test_Field_convolution_filter(self):
+        return
         if self.test_only and inspect.stack()[0][3] not in self.test_only:
             return
             
@@ -33,11 +35,29 @@ class MathTest(unittest.TestCase):
 
             f = cf.read(self.filename1)[0]
             
+            # Test user weights in different modes
             for mode in ('reflect', 'constant', 'nearest', 'mirror', 'wrap'):
-                g = f.filter(weights, mode=mode)
+                g = f.convolution_filter(('user', weights), mode=mode, cval=0.0)
                 self.assertTrue((g.array == convolve1d(f.array, weights,
                                                        mode=mode)).all())
             #--- End: for
+
+            # Test named filters with default parameters
+            for window in ('boxcar', 'triang', 'blackman', 'hamming', 'hann',
+                           'bartlett', 'flattop', 'parzen', 'bohman',
+                           'blackmanharris', 'nuttall', 'barthann', 'cosine',
+                           ('kaiser', 5), ('gaussian', 2.5),
+                           ('general_gaussian',0.5, 2.5),
+                           ('slepian', 0.3), ('chebwin', 50), ('tukey', 1)):
+                g = f. convolution_filter(window, 5, mode='reflect')
+                self.assertTrue((g.array == convolve1d(f.array,
+                                    get_window(window, 5, False))).all())
+            #--- End: for
+
+            # Exponential window is a special case
+            g = f.convolution_filter(('exponential', 2.5), 5, mode='reflect')
+            self.assertTrue((g.array == convolve1d(f.array,
+                    get_window(('exponential', None, 2.5), 5, False))).all())
         #--- End: for
 
         cf.CHUNKSIZE(self.original_chunksize)
